#[repr(C)]pub struct BandRssiAdjustment {
pub band: WlanBand,
pub rssi_adjustment: i8,
}Expand description
An adjustment to be made to the observed RSSI values for BSSs in the specified band.
Fields
band: WlanBandrssi_adjustment: i8Trait Implementations
Sourceimpl Clone for BandRssiAdjustment
impl Clone for BandRssiAdjustment
Sourcefn clone(&self) -> BandRssiAdjustment
fn clone(&self) -> BandRssiAdjustment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BandRssiAdjustment
impl Debug for BandRssiAdjustment
Sourceimpl<'a, ___E> Encode<BandRssiAdjustment, ___E> for &'a BandRssiAdjustmentwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<BandRssiAdjustment, ___E> for &'a BandRssiAdjustmentwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BandRssiAdjustment>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BandRssiAdjustment>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<BandRssiAdjustment, ___E> for BandRssiAdjustmentwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<BandRssiAdjustment, ___E> for BandRssiAdjustmentwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, BandRssiAdjustment>
const COPY_OPTIMIZATION: CopyOptimization<Self, BandRssiAdjustment>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<BandRssiAdjustment>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<BandRssiAdjustment>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, BandRssiAdjustment>, ___E> for &'a BandRssiAdjustment
impl<'a, ___E> EncodeOption<Box<'static, BandRssiAdjustment>, ___E> for &'a BandRssiAdjustment
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BandRssiAdjustment>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BandRssiAdjustment>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, BandRssiAdjustment>, ___E> for BandRssiAdjustment
impl<___E> EncodeOption<Box<'static, BandRssiAdjustment>, ___E> for BandRssiAdjustment
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, BandRssiAdjustment>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, BandRssiAdjustment>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<BandRssiAdjustment> for BandRssiAdjustment
impl FromWire<BandRssiAdjustment> for BandRssiAdjustment
Sourceconst COPY_OPTIMIZATION: CopyOptimization<BandRssiAdjustment, Self>
const COPY_OPTIMIZATION: CopyOptimization<BandRssiAdjustment, Self>
Sourcefn from_wire(wire: BandRssiAdjustment) -> Self
fn from_wire(wire: BandRssiAdjustment) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<BandRssiAdjustment> for BandRssiAdjustment
impl FromWireRef<BandRssiAdjustment> for BandRssiAdjustment
Sourcefn from_wire_ref(wire: &BandRssiAdjustment) -> Self
fn from_wire_ref(wire: &BandRssiAdjustment) -> Self
Converts the given reference to this type.
Sourceimpl Hash for BandRssiAdjustment
impl Hash for BandRssiAdjustment
Sourceimpl Ord for BandRssiAdjustment
impl Ord for BandRssiAdjustment
Sourcefn cmp(&self, other: &BandRssiAdjustment) -> Ordering
fn cmp(&self, other: &BandRssiAdjustment) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for BandRssiAdjustment
impl PartialEq for BandRssiAdjustment
Sourcefn eq(&self, other: &BandRssiAdjustment) -> bool
fn eq(&self, other: &BandRssiAdjustment) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for BandRssiAdjustment
impl PartialOrd for BandRssiAdjustment
impl Copy for BandRssiAdjustment
impl Eq for BandRssiAdjustment
impl StructuralPartialEq for BandRssiAdjustment