pub struct DfsFeature {
pub supported: Option<bool>,
}Expand description
Dynamic Frequency Selection. See IEEE 802.11-2016 11.9. This is a spectrum management feature, usable for fullmac or softmac.
Fields
supported: Option<bool>Trait Implementations
Sourceimpl Clone for DfsFeature
impl Clone for DfsFeature
Sourcefn clone(&self) -> DfsFeature
fn clone(&self) -> DfsFeature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DfsFeature
impl Debug for DfsFeature
Sourceimpl Default for DfsFeature
impl Default for DfsFeature
Sourcefn default() -> DfsFeature
fn default() -> DfsFeature
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<DfsFeature<'static>, ___E> for &'a DfsFeaturewhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<DfsFeature<'static>, ___E> for &'a DfsFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<DfsFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<DfsFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<DfsFeature<'static>, ___E> for DfsFeaturewhere
___E: Encoder + ?Sized,
impl<___E> Encode<DfsFeature<'static>, ___E> for DfsFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<DfsFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<DfsFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<DfsFeature<'de>> for DfsFeature
impl<'de> FromWire<DfsFeature<'de>> for DfsFeature
Sourcefn from_wire(wire_: DfsFeature<'de>) -> Self
fn from_wire(wire_: DfsFeature<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<DfsFeature<'de>> for DfsFeature
impl<'de> FromWireRef<DfsFeature<'de>> for DfsFeature
Sourcefn from_wire_ref(wire: &DfsFeature<'de>) -> Self
fn from_wire_ref(wire: &DfsFeature<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for DfsFeature
impl Hash for DfsFeature
Sourceimpl Ord for DfsFeature
impl Ord for DfsFeature
Sourcefn cmp(&self, other: &DfsFeature) -> Ordering
fn cmp(&self, other: &DfsFeature) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DfsFeature
impl PartialEq for DfsFeature
Sourcefn eq(&self, other: &DfsFeature) -> bool
fn eq(&self, other: &DfsFeature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for DfsFeature
impl PartialOrd for DfsFeature
impl Copy for DfsFeature
impl Eq for DfsFeature
impl StructuralPartialEq for DfsFeature