pub struct MfpFeature {
pub supported: Option<bool>,
}Expand description
Management Frame Protection. See IEEE 802.11-2016 4.5.4.9. This is a security feature, usable for fullmac or softmac.
Fields
supported: Option<bool>Trait Implementations
Sourceimpl Clone for MfpFeature
impl Clone for MfpFeature
Sourcefn clone(&self) -> MfpFeature
fn clone(&self) -> MfpFeature
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MfpFeature
impl Debug for MfpFeature
Sourceimpl Default for MfpFeature
impl Default for MfpFeature
Sourcefn default() -> MfpFeature
fn default() -> MfpFeature
Returns the “default value” for a type. Read more
Sourceimpl<'a, ___E> Encode<MfpFeature<'static>, ___E> for &'a MfpFeaturewhere
___E: Encoder + ?Sized,
impl<'a, ___E> Encode<MfpFeature<'static>, ___E> for &'a MfpFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<MfpFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<MfpFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MfpFeature<'static>, ___E> for MfpFeaturewhere
___E: Encoder + ?Sized,
impl<___E> Encode<MfpFeature<'static>, ___E> for MfpFeaturewhere
___E: Encoder + ?Sized,
Sourcefn encode(
self,
encoder: &mut ___E,
out: &mut MaybeUninit<MfpFeature<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder: &mut ___E, out: &mut MaybeUninit<MfpFeature<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'de> FromWire<MfpFeature<'de>> for MfpFeature
impl<'de> FromWire<MfpFeature<'de>> for MfpFeature
Sourcefn from_wire(wire_: MfpFeature<'de>) -> Self
fn from_wire(wire_: MfpFeature<'de>) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MfpFeature<'de>> for MfpFeature
impl<'de> FromWireRef<MfpFeature<'de>> for MfpFeature
Sourcefn from_wire_ref(wire: &MfpFeature<'de>) -> Self
fn from_wire_ref(wire: &MfpFeature<'de>) -> Self
Converts the given reference to this type.
Sourceimpl Hash for MfpFeature
impl Hash for MfpFeature
Sourceimpl Ord for MfpFeature
impl Ord for MfpFeature
Sourcefn cmp(&self, other: &MfpFeature) -> Ordering
fn cmp(&self, other: &MfpFeature) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MfpFeature
impl PartialEq for MfpFeature
Sourcefn eq(&self, other: &MfpFeature) -> bool
fn eq(&self, other: &MfpFeature) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MfpFeature
impl PartialOrd for MfpFeature
impl Copy for MfpFeature
impl Eq for MfpFeature
impl StructuralPartialEq for MfpFeature