#[repr(C)]pub struct ScheduledScanPlan {
pub interval: u32,
pub iterations: u32,
}Expand description
A scan plan defines the number of scan iterations and the interval between scans. Time of first scan (e.g. t=0, t=interval, etc.) is determined by the firmware.
Fields
interval: u32iterations: u32Trait Implementations
Sourceimpl Clone for ScheduledScanPlan
impl Clone for ScheduledScanPlan
Sourcefn clone(&self) -> ScheduledScanPlan
fn clone(&self) -> ScheduledScanPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScheduledScanPlan
impl Debug for ScheduledScanPlan
Sourceimpl<'a, ___E> Encode<ScheduledScanPlan, ___E> for &'a ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ScheduledScanPlan, ___E> for &'a ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ScheduledScanPlan>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ScheduledScanPlan>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ScheduledScanPlan, ___E> for ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ScheduledScanPlan, ___E> for ScheduledScanPlanwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ScheduledScanPlan>
const COPY_OPTIMIZATION: CopyOptimization<Self, ScheduledScanPlan>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ScheduledScanPlan>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ScheduledScanPlan>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ScheduledScanPlan>, ___E> for &'a ScheduledScanPlan
impl<'a, ___E> EncodeOption<Box<'static, ScheduledScanPlan>, ___E> for &'a ScheduledScanPlan
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ScheduledScanPlan>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ScheduledScanPlan>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ScheduledScanPlan>, ___E> for ScheduledScanPlan
impl<___E> EncodeOption<Box<'static, ScheduledScanPlan>, ___E> for ScheduledScanPlan
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ScheduledScanPlan>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ScheduledScanPlan>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ScheduledScanPlan> for ScheduledScanPlan
impl FromWire<ScheduledScanPlan> for ScheduledScanPlan
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ScheduledScanPlan, Self>
const COPY_OPTIMIZATION: CopyOptimization<ScheduledScanPlan, Self>
Sourcefn from_wire(wire: ScheduledScanPlan) -> Self
fn from_wire(wire: ScheduledScanPlan) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ScheduledScanPlan> for ScheduledScanPlan
impl FromWireRef<ScheduledScanPlan> for ScheduledScanPlan
Sourcefn from_wire_ref(wire: &ScheduledScanPlan) -> Self
fn from_wire_ref(wire: &ScheduledScanPlan) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ScheduledScanPlan
impl Hash for ScheduledScanPlan
Sourceimpl Ord for ScheduledScanPlan
impl Ord for ScheduledScanPlan
Sourcefn cmp(&self, other: &ScheduledScanPlan) -> Ordering
fn cmp(&self, other: &ScheduledScanPlan) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ScheduledScanPlan
impl PartialEq for ScheduledScanPlan
Sourcefn eq(&self, other: &ScheduledScanPlan) -> bool
fn eq(&self, other: &ScheduledScanPlan) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ScheduledScanPlan
impl PartialOrd for ScheduledScanPlan
impl Copy for ScheduledScanPlan
impl Eq for ScheduledScanPlan
impl StructuralPartialEq for ScheduledScanPlan