pub struct WlanChannel {
pub primary: u8,
pub cbw: ChannelBandwidth,
pub secondary80: u8,
}Fields
primary: u8cbw: ChannelBandwidthsecondary80: u8Trait Implementations
Sourceimpl Clone for WlanChannel
impl Clone for WlanChannel
Sourcefn clone(&self) -> WlanChannel
fn clone(&self) -> WlanChannel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WlanChannel
impl Debug for WlanChannel
Sourceimpl<'a, ___E> Encode<WlanChannel, ___E> for &'a WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<WlanChannel, ___E> for &'a WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanChannel>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanChannel>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<WlanChannel, ___E> for WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<WlanChannel, ___E> for WlanChannelwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<WlanChannel>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<WlanChannel>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, WlanChannel>, ___E> for &'a WlanChannel
impl<'a, ___E> EncodeOption<Box<'static, WlanChannel>, ___E> for &'a WlanChannel
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanChannel>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanChannel>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, WlanChannel>, ___E> for WlanChannel
impl<___E> EncodeOption<Box<'static, WlanChannel>, ___E> for WlanChannel
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, WlanChannel>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, WlanChannel>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<WlanChannel> for WlanChannel
impl FromWire<WlanChannel> for WlanChannel
Sourcefn from_wire(wire: WlanChannel) -> Self
fn from_wire(wire: WlanChannel) -> Self
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl FromWireRef<WlanChannel> for WlanChannel
impl FromWireRef<WlanChannel> for WlanChannel
Sourcefn from_wire_ref(wire: &WlanChannel) -> Self
fn from_wire_ref(wire: &WlanChannel) -> Self
Converts the given reference to this type.
Sourceimpl Hash for WlanChannel
impl Hash for WlanChannel
Sourceimpl Ord for WlanChannel
impl Ord for WlanChannel
Sourcefn cmp(&self, other: &WlanChannel) -> Ordering
fn cmp(&self, other: &WlanChannel) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for WlanChannel
impl PartialEq for WlanChannel
Sourcefn eq(&self, other: &WlanChannel) -> bool
fn eq(&self, other: &WlanChannel) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WlanChannel
impl PartialOrd for WlanChannel
impl Copy for WlanChannel
impl Eq for WlanChannel
impl StructuralPartialEq for WlanChannel